"use strict";
var js_yaml_1 = require('js-yaml');
var path_1 = require('path');
var fs_1 = require('fs');
var electron_1 = require('electron');
function load() {
    if (this.user_config) {
        return this.user_config;
    }
    var config_dir = electron_1.app.getPath('userData');
    var file = path_1.join(config_dir, 'config.yml');
    var default_config = {
        linter: 'remark-lint',
        file_ext: {
            markdown: ['md', 'markdown', 'mkd'],
            html: ['html'],
        },
        width: 920,
        height: 800,
        ignore_path_pattern: '[\\\\/]\\.',
        voice: {
            enabled: false,
            source: '../voices/bow.mp3',
        },
        drawer: {
            responsive: true,
        },
        menu: {
            visible: true,
        },
        hide_title_bar: false,
        markdown: {
            font_size: '',
            css_path: '../../bower_components/github-markdown-css/github-markdown.css',
            code_theme: 'github',
        },
        shortcuts: {
            'j': 'PageDown',
            'k': 'PageUp',
            'down': 'PageDown',
            'up': 'PageUp',
            'pagedown': 'PageDown',
            'pageup': 'PageUp',
            'h': 'PageLeft',
            'l': 'PageRight',
            'left': 'PageLeft',
            'right': 'PageRight',
            'i': 'PageTop',
            'm': 'PageBottom',
            'home': 'PageTop',
            'end': 'PageBottom',
            'ctrl+p': 'ChangePath',
            'ctrl+l': 'Lint',
            'r': 'Reload',
            's': 'Search',
            'o': 'Outline',
        },
    };
    function mergeConfig(c1, c2) {
        for (var k in c2) {
            var v2 = c2[k];
            if (k in c1) {
                var v1 = c1[k];
                if (typeof (v1) === 'object' && typeof (v2) === 'object') {
                    mergeConfig(v1, v2);
                }
                continue;
            }
            c1[k] = c2[k];
        }
    }
    try {
        this.user_config = js_yaml_1.load(fs_1.readFileSync(file, { encoding: 'utf8' }));
        mergeConfig(this.user_config, default_config);
    }
    catch (e) {
        console.log('No configuration file is found: ' + file);
        this.user_config = default_config;
    }
    this.user_config._config_dir_path = config_dir;
    return this.user_config;
}
exports.load = load;
//# sourceMappingURL=config.js.map