"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var initial_path = require("../../browser/initial_path");
var path = require("path");
var assert = require("power-assert");
function argv() {
    var a = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        a[_i] = arguments[_i];
    }
    return ['path/to/Electron', 'path/to/Shiba'].concat(a);
}
describe('#initial_path()', function () {
    var argv_save;
    var cwd_save;
    beforeEach(function () {
        argv_save = process.argv;
        cwd_save = process.cwd();
    });
    afterEach(function () {
        process.argv = argv_save;
        process.chdir(cwd_save);
    });
    it('returns cwd when no argument is specified in general platform', function () {
        process.argv = argv();
        assert.equal(initial_path(''), process.cwd());
    });
    it('returns document directory if started with Shiba.app in darwin', function () {
        if (process.platform === 'darwin') {
            process.argv = argv();
            process.chdir('/');
            assert(/Documents$/.test(initial_path('')));
        }
    });
    it('returns the specified path if it exists', function () {
        process.argv = argv('./README.md');
        assert.equal(initial_path(''), path.resolve('./README.md'));
    });
    it('returns default path if specified path does not exist', function () {
        process.argv = argv('/this/file/does/not/exist');
        assert.equal(initial_path(''), process.cwd());
    });
    it('returns the last argument of argv if multiple argument specified', function () {
        process.argv = argv('foo', 'bar', './README.md');
        assert.equal(initial_path(''), path.resolve('./README.md'));
    });
    it('considers the case where the Electron binary is directly executed', function () {
        var exe = '/path/to/Shiba';
        if (process.platform === 'win32') {
            exe = 'C:\\path\\to\\Shiba.exe';
        }
        process.argv = [exe];
        assert.equal(initial_path(''), process.cwd());
        process.argv = [exe, './README.md'];
        assert.equal(initial_path(''), path.resolve('./README.md'));
    });
});
//# sourceMappingURL=initial_path_test.js.map