"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var linter_1 = require("../../browser/linter");
var dummy_webcontents_1 = require("./dummy_webcontents");
var assert = require("power-assert");
var path_1 = require("path");
var electron_1 = require("electron");
var ok_doc = path_1.join(__dirname, '..', '..', 'doc', 'ok.md');
var not_ok_doc = path_1.join(__dirname, '..', '..', 'doc', 'notok.md');
var not_ok_doc_remark = path_1.join(__dirname, '..', '..', 'doc', 'notok_remark.md');
context('Linter', function () {
    describe('constructor', function () {
        var dummy_contents = new dummy_webcontents_1.default();
        it('accepts default linter name', function () {
            assert(new linter_1.default(dummy_contents, 'markdownlint', {}));
        });
        it("accepts names 'markdownlint', 'remark-lint' and 'none'", function () {
            assert(new linter_1.default(dummy_contents, 'markdownlint', {}).lint_url);
            assert(new linter_1.default(dummy_contents, 'markdownlint', {}).lint);
            assert(new linter_1.default(dummy_contents, 'remark-lint', {}).lint_url);
            assert(new linter_1.default(dummy_contents, 'remark-lint', {}).lint);
            assert(!new linter_1.default(dummy_contents, 'none', {}).lint_url);
            assert(new linter_1.default(dummy_contents, 'none', {}).lint);
            assert(!new linter_1.default(dummy_contents, 'unknown_linter_name', {}).lint_url);
            assert(new linter_1.default(dummy_contents, 'unknown_linter_name', {}).lint);
        });
    });
    describe('markdownlint', function () {
        it('lints markdown source', function (done) {
            var c = new dummy_webcontents_1.default();
            var linter = new linter_1.default(c, 'markdownlint', {});
            c.once('shiba:notify-linter-result', function (_, msgs) {
                assert(msgs.length > 0);
                done();
            });
            linter.lint(not_ok_doc);
        });
        it('lints markdown source', function (done) {
            var c = new dummy_webcontents_1.default();
            var linter = new linter_1.default(c, 'markdownlint', {});
            c.once('shiba:notify-linter-result', function (_, msgs) {
                assert(msgs.length === 0);
                done();
            });
            linter.lint(ok_doc);
        });
    });
    describe('remark-lint', function () {
        it('reports some errors', function (done) {
            var c = new dummy_webcontents_1.default();
            var linter = new linter_1.default(c, 'remark-lint', {});
            c.once('shiba:notify-linter-result', function (_, msgs) {
                assert(msgs.length > 0);
                done();
            });
            linter.lint(not_ok_doc_remark);
        });
        it('reports no error for good doc', function (done) {
            var c = new dummy_webcontents_1.default();
            var linter = new linter_1.default(c, 'remark-lint', {});
            c.once('shiba:notify-linter-result', function (_, msgs) {
                assert(msgs.length === 0);
                done();
            });
            linter.lint(ok_doc);
        });
        it('refers "plugins" entry of config', function (done) {
            var c = new dummy_webcontents_1.default();
            var linter = new linter_1.default(c, 'remark-lint', { plugins: [] });
            c.once('shiba:notify-linter-result', function (_, msgs) {
                assert(msgs.length === 0);
                done();
            });
            linter.lint(not_ok_doc_remark);
        });
    });
    describe('none', function () {
        it('lints markdown source', function (done) {
            var c = new dummy_webcontents_1.default();
            var linter = new linter_1.default(c, 'remark-lint', {});
            c.once('shiba:notify-linter-result', function (_, msgs) {
                assert(msgs.length === 0);
                done();
            });
            linter.lint(ok_doc);
        });
    });
    describe('invalid linter name', function () {
        it('does nothing and never fires callback', function () {
            var c = new dummy_webcontents_1.default();
            var linter = new linter_1.default(c, 'invalid-linter-name', {});
            linter.lint(not_ok_doc);
        });
    });
    it('does not crash on invalid file path', function () {
        var c = new dummy_webcontents_1.default();
        var linter = new linter_1.default(c, 'remark-lint', {});
        linter.lint('path/to/not/existing/file');
        linter.lint('');
    });
    it('returns linter\'s rules URL via IPC', function (done) {
        var c = new dummy_webcontents_1.default();
        new linter_1.default(c, 'remark-lint', {});
        c.once('shiba:return-lint-rule-url', function (_, url) {
            assert.equal(url.indexOf('http'), 0);
            done();
        });
        electron_1.ipcMain.emit('shiba:request-lint-rule-url', {});
    });
});
//# sourceMappingURL=linter_test.js.map