"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = require("path");
var assert = require("power-assert");
var touch = require("touch");
var watcher_1 = require("../../browser/watcher");
var dummy_webcontents_1 = require("./dummy_webcontents");
var electron_1 = require("electron");
var docdir = path_1.join(__dirname, '..', '..', 'doc');
var doc1 = path_1.join(docdir, 'ok.md');
var doc2 = path_1.join(docdir, 'notok.md');
var config = {
    linter: 'none',
    lint_options: {},
    file_ext: {
        markdown: ['md', 'markdown'],
    },
    ignore_path_pattern: '[\\\\/]\\.',
};
context('WatchDog', function () {
    describe('#constructor', function () {
        it('generates watcher object with callbacks', function () {
            assert(new watcher_1.default(config));
        });
    });
    describe('#getDocumentKindFor', function () {
        var watchdog = new watcher_1.default(config);
        it('detects file extension from argument', function () {
            var kind;
            kind = watchdog.getDocumentKindFor('md');
            assert(kind === 'markdown');
            kind = watchdog.getDocumentKindFor('markdown');
            assert(kind === 'markdown');
        });
        it('returns undefined for unknown extension', function () {
            assert(watchdog.getDocumentKindFor('unknown-extension') === undefined);
        });
    });
    describe("Sending path to 'shiba:notify-path'", function () {
        it('ignores invalid path', function () {
            var watchdog = new watcher_1.default(config);
            watchdog.wakeup(new dummy_webcontents_1.default());
            electron_1.ipcMain.emit('shiba:notify-path', {}, '');
            electron_1.ipcMain.emit('shiba:notify-path', {}, 'invalid-path');
        });
        it('starts watcher on directory', function () {
            var c = new dummy_webcontents_1.default();
            c.once('shiba-notify-content-updated', function () {
                assert(false);
            });
            var watchdog = new watcher_1.default(config);
            watchdog.wakeup(c);
            electron_1.ipcMain.emit('shiba:notify-path', {}, docdir);
            assert(watchdog.eyes);
            assert(watchdog.watching_path === docdir);
            watchdog.eyes.close();
        });
        it('starts watcher and notify first update on file path', function (done) {
            var watchdog = new watcher_1.default(config);
            var c = new dummy_webcontents_1.default();
            c.once('shiba:notify-content-updated', function (_, kind, file) {
                assert(kind === 'markdown');
                assert(file === doc1);
                assert(watchdog.watching_path === doc1);
                done();
            });
            watchdog.wakeup(c);
            electron_1.ipcMain.emit('shiba:notify-path', {}, doc1);
            assert(watchdog.eyes);
        });
    });
    describe('path watcher', function () {
        var c = new dummy_webcontents_1.default();
        var watchdog = new watcher_1.default(config);
        watchdog.wakeup(c);
        it('watches file path', function (done) {
            electron_1.ipcMain.emit('shiba:notify-path', {}, doc1);
            c.once('shiba:notify-content-updated', function (_, kind, file) {
                assert(kind === 'markdown');
                assert(file === doc1);
                watchdog.eyes.close();
                done();
            });
            setTimeout(function () { return touch(doc1); }, 100);
        });
        it('watches directory path', function (done) {
            electron_1.ipcMain.emit('shiba:notify-path', {}, docdir);
            c.once('shiba:notify-content-updated', function (_, kind, file) {
                assert(kind === 'markdown');
                assert(file === doc1);
                watchdog.eyes.close();
                done();
            });
            setTimeout(function () { return touch(doc1); }, 100);
        });
        it('changes watching path', function (done) {
            electron_1.ipcMain.emit('shiba:notify-path', {}, doc1);
            c.once('shiba:notify-content-updated', function (_, kind, file) {
                assert(kind === 'markdown');
                assert(file === doc2);
                watchdog.eyes.close();
                done();
            });
            electron_1.ipcMain.emit('shiba:notify-path', {}, doc2);
        });
    });
});
//# sourceMappingURL=watcher_test.js.map